import { AppConfig } from "./app-config.model";
import { debug } from "console";
import { Etcd3 } from "etcd3";
import { load } from "js-yaml";
import { hostname } from "os";
import { getEtcdInstance } from "./etcd-connection";

class ConfigLoader {
  private etcd: Etcd3;

  private readonly currHost = hostname();
  private readonly configKeyPrefix = "share/config";

  constructor(config: AppConfig) {
    this.etcd = getEtcdInstance(config);
  }

  async loadConfig(configKey: string): Promise<any> {
    const str = await this.etcd
      .get(`${this.configKeyPrefix}/${this.currHost}/${configKey}`)
      .string();

    if (!str) {
      debug("config-loader", `No config found for ${configKey}`);
      return null;
    }
    return load(str);
  }
}
